AvoidRawScaffold class
禁止业务页面直接使用 Scaffold(...);必须用 flutter_spine 提供的
AppPageScaffold / AppFormPageScaffold /
AppBottomSheetScaffold / AppRawPage 之一。
这样所有页面自动获得:统一 AppBar、SafeArea、键盘收起、Effect 分发、 以及与 MVVM 基类的默认联动。
豁免
这些位置允许裸 Scaffold:
flutter_spine自身的 scaffold 实现:package/flutter_spine/lib/src/ui/scaffold/**- 测试 fixture:路径含
/test/或/test_fixtures/ - 文档 / 示例:路径含
/example/
Constructors
- AvoidRawScaffold()
-
const
Properties
- code → LintCode
-
The
LintCodethat thisLintRulemay emit.finalinherited - enabledByDefault → bool
-
Whether the lint rule is on or off by default in an empty analysis_options.yaml
no setterinherited
-
filesToAnalyze
→ List<
String> -
A list of glob patterns matching the files that run cares about.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFixes(
) → List< Fix> -
Obtains the list of
Fixassociated with thisLintRule.inherited -
isEnabled(
CustomLintConfigs configs) → bool -
Checks whether this lint rule is enabled in a configuration file.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
CustomLintResolver resolver, ErrorReporter reporter, CustomLintContext context) → void - Emits lints for a given file.
-
startUp(
CustomLintResolver resolver, CustomLintContext context) → Future< void> -
Emits lints for a given file.
inherited
-
testAnalyzeAndRun(
File file) → Future< List< AnalysisError> > -
Analyze a Dart file and runs this assist in test mode.
inherited
-
testRun(
ResolvedUnitResult result, {Pubspec? pubspec}) → Future< List< AnalysisError> > -
Runs this assist in test mode.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited